CreateNewEntry: Create dataframe holding test results

Description Usage Arguments Value

View source: R/Internal_Journal.R

Description

Runs a script multiple times and returns the benchmark results for the runs.

Usage

1
CreateNewEntry(script, times, warmup, hash)

Arguments

script

Name of the script (with .R extension)

times

Number of times to benchmark script (not including warmup)

warmup

Number of times to run script first as a warmup

hash

commit hash. Intended to be used only when using git hooks

Value

A dataframe with columns for the script name, the time taken to run the script, the package version (or commit hash), the version of R, the date of the test, and the name of the system


nathansam/BenchJournal documentation built on June 21, 2020, 10:01 p.m.