GetPkgName: Find name of current package

Description Usage Value

View source: R/Internal_Journal.R

Description

Finds name of package being developed for by finding the current working directory and using the lowest level of the directory

Usage

1

Value

String. The name of the package being developed


nathansam/BenchJournal documentation built on June 21, 2020, 10:01 p.m.