Init: Create folders in /man required for BenchJournal

Description Usage

View source: R/User_Journal.R

Description

Sets up a BenchmarkJournal subdirectory in the /man directory. Inside this subdirectory, a csv file is created to hold the benchmark results and two additional folders. One for holding scripts to be benchmarked, called scripts. and one to hold plots, helpfully called plots.The BenchmarkJournal subdirectory is also added to .Rbuildignore. The user is asked if they wish to use the githook workflow or manually run NewEntry

Usage

1
Init()

nathansam/BenchJournal documentation built on June 21, 2020, 10:01 p.m.