JournalBoxPlot: Create interactive boxplots of benchmark results from...

Description Usage Arguments

View source: R/plot.R

Description

Uses ggplot2 and plotly to create boxplots for each script in man/BenchJournal/scripts by date.

Usage

1
JournalBoxPlot(units = "s", rm.outliers = FALSE)

Arguments

units

The unit of time to use for the plot. Either 's' (seconds), 'ms' (milliseconds), 'us' (microseconds), or 'ns' (nanoseconds).

rm.outliers

Logical. If TRUE then outliers will not be included in the plot. Defaults to FALSE.


nathansam/BenchJournal documentation built on June 21, 2020, 10:01 p.m.