NewJournal: Create a new journal file

Description Usage Arguments

View source: R/User_Journal.R

Description

Creates a new csv file to journal benchmark results, overwriting the previous results. The user is asked to confirm overwriting an existing file unless ask != TRUE

Usage

1

Arguments

ask

Logical. If TRUE then the user is asked to confirm overwriting the journal csv file.


nathansam/BenchJournal documentation built on June 21, 2020, 10:01 p.m.