RemoveOutliers: Remove outliers from journal

Description Usage Arguments Value

View source: R/Internal_Journal.R

Description

Remove observations from a journal with outlier run times.

Usage

1

Arguments

df

dataframe in the format of journal

Value

A dataframe where observations with outlier run times have been removed


nathansam/BenchJournal documentation built on June 21, 2020, 10:01 p.m.