Description Usage Arguments Value
View source: R/Internal_Journal.R
Runs a script multiple times and returns the benchmark results for the runs.
1 | CreateNewEntry(script, times, warmup, hash)
|
script |
Name of the script (with .R extension) |
times |
Number of times to benchmark script (not including warmup) |
warmup |
Number of times to run script first as a warmup |
hash |
commit hash. Intended to be used only when using git hooks |
A dataframe with columns for the script name, the time taken to run the script, the package version (or commit hash), the version of R, the date of the test, and the name of the system
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.