View source: R/Internal_Journal.R
Finds name of package being developed for by finding the current working directory and using the lowest level of the directory
1 |
String. The name of the package being developed
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.