Sets up a BenchmarkJournal subdirectory in the
/man directory. Inside this subdirectory, a csv file is created to
hold the benchmark results and two additional folders. One for holding
scripts to be benchmarked, called scripts. and one to hold plots,
helpfully called plots.The BenchmarkJournal subdirectory is
also added to .Rbuildignore. The user is asked if they wish to use the
githook workflow or manually run NewEntry
1 | Init()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.