Uses ggplot2 and plotly to create boxplots for
each script in man/BenchJournal/scripts by date.
1 | JournalBoxPlot(units = "s", rm.outliers = FALSE)
|
units |
The unit of time to use for the plot. Either 's' (seconds), 'ms' (milliseconds), 'us' (microseconds), or 'ns' (nanoseconds). |
rm.outliers |
Logical. If TRUE then outliers will not be included in the plot. Defaults to FALSE. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.