Creates a new csv file to journal benchmark results, overwriting the previous results. The user is asked to confirm overwriting an existing file unless ask != TRUE
1 | NewJournal(ask = TRUE)
|
ask |
Logical. If TRUE then the user is asked to confirm overwriting the journal csv file. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.